@@ -1,6 +1,7 @@
 package cmdpipe
 
 import (
+	"errors"
 	"io"
 
 	"github.com/lmorg/murex/lang"
@@ -32,6 +33,10 @@ func cmdMurexNamedPipe(p *lang.Process) error {
 		}
 	}
 
+	if pipe == nil {
+		return errors.New("STDIN is null")
+	}
+
 	if p.IsMethod {
 		pipe.SetDataType(p.Stdin.GetDataType())
 		_, err = io.Copy(pipe, p.Stdin)
