@@ -3,7 +3,6 @@ package processes
 import (
 	"fmt"
 
-	"github.com/lmorg/murex/config/defaults"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/types"
 )
@@ -11,35 +10,6 @@ import (
 func init() {
 	lang.DefineFunction("fid-kill", cmdFidKill, types.Null)
 	lang.DefineFunction("fid-killall", cmdKillAll, types.Null)
-
-	defaults.AppendProfile(`
-private autocomplete.fid-kill {
-	# Returns a 2D array FIDs 
-    fid-list: --jsonl -> [ FID Command Parameters ]
-}
-
-test unit private autocomplete.fid-kill {
-    "StdoutRegex": (^\["FID","Command","Parameters"\]\n.*(["[0-9]+",")),
-	"StdoutType":  "jsonl",
-	"ExitNum": 0,
-	"StdoutBlock": ({
-        -> len -> set len;
-        if { = len>0 } then {
-            out "Len greater than 0"
-        } else {
-            err "No elements returned"
-        }
-    })
-}
-
-autocomplete: set fid-kill {
-    [{
-        "DynamicDesc": ({ autocomplete.fid-kill }),
-        "ListView": true,
-        "AllowMultiple": true
-    }]
-}
-`)
 }
 
 func cmdFidKill(p *lang.Process) error {
