@@ -25,7 +25,7 @@ func cmdEvent(p *lang.Process) error {
 	}
 
 	if events[et] == nil {
-		return fmt.Errorf("No event-type known for `%s`.\nRun `runtime --events` to view which events are compiled in", et)
+		return fmt.Errorf("no event-type known for `%s`.\nRun `runtime --events` to view which events are compiled in", et)
 	}
 
 	nameInterrupt, err := p.Parameters.String(1)
@@ -35,7 +35,7 @@ func cmdEvent(p *lang.Process) error {
 
 	split := rxNameInterruptSyntax.FindAllStringSubmatch(nameInterrupt, 1)
 	if len(split) != 1 || len(split[0]) != 3 {
-		return fmt.Errorf("Invalid syntax: `%s`. Expected: `name=interrupt`", nameInterrupt)
+		return fmt.Errorf("invalid syntax: `%s`. Expected: `name=interrupt`", nameInterrupt)
 	}
 
 	name := split[0][1]
@@ -59,7 +59,7 @@ func cmdUnevent(p *lang.Process) error {
 	}
 
 	if events[et] == nil {
-		return fmt.Errorf("No event-type known for `%s`.\nRun `runtime --events` to view which events are compiled in", et)
+		return fmt.Errorf("no event-type known for `%s`.\nRun `runtime --events` to view which events are compiled in", et)
 	}
 
 	name, err := p.Parameters.String(1)
