@@ -3,6 +3,7 @@ package streams
 import (
 	"context"
 	"io"
+	"os"
 
 	"github.com/lmorg/murex/config"
 	"github.com/lmorg/murex/lang/stdio"
@@ -36,6 +37,10 @@ func (tee *Tee) IsTTY() bool {
 	return tee.primary.IsTTY()
 }
 
+func (tee *Tee) File() *os.File {
+	return tee.primary.File()
+}
+
 // Stats is stored against the primary STDOUT stream in tee
 func (tee *Tee) Stats() (uint64, uint64) {
 	return tee.primary.Stats()
