@@ -9,10 +9,11 @@ export default sidebar({
         "/install/",
         "compatibility/", 
         "/changelog/",
-        "/blog/",
-        { text: "Language Tour", link: "tour.html", icon: "life-ring" }, 
-        { text: "Rosetta Stone", link: "user-guide/rosetta-stone.html", icon: "language" },
+        { text: "Language Tour", link: "tour.html", icon: "plane-departure" }, 
+        { text: "Rosetta Stone", link: "user-guide/rosetta-stone.html", icon: "table" },
+        { text: "Operators And Tokens", link: "user-guide/operators-and-tokens.html", icon: "hashtag" },
         "/contributing",
+        "/blog/",
       ],
       collapsible: true,
     },
@@ -32,21 +33,21 @@ export default sidebar({
     },
     {
       text: "Operators And Tokens",
-      icon: "equals",
+      icon: "hashtag",
       prefix: "parser/",
       children: "structure",
       collapsible: true,
     },
     {
       text: "Builtins",
-      icon: "terminal",
+      icon: "cubes",
       prefix: "commands/",
       children: "structure",
       collapsible: true,
     },
     {
       text: "Optional Builtins",
-      icon: "terminal",
+      icon: "cube",
       prefix: "optional/",
       children: "structure",
       collapsible: true,
@@ -60,7 +61,7 @@ export default sidebar({
     },
     {
       text: "Data Types",
-      icon: "table",
+      icon: "file-contract",
       prefix: "types/",
       children: "structure",
       collapsible: true,
