@@ -7,7 +7,7 @@ import (
 // MarshalData is a global marshaller which should be called from within murex
 // builtin commands (etc).
 // See docs/apis/marshaldata.md for more details
-func MarshalData(p *Process, dataType string, data interface{}) (b []byte, err error) {
+func MarshalData(p *Process, dataType string, data interface{}) ([]byte, error) {
 	// This is one of the very few maps in Murex which isn't hidden behind a sync
 	// lock of one description or other. The rational is that even mutexes can
 	// add a noticeable overhead on the performance of tight loops and I expect
@@ -20,10 +20,10 @@ func MarshalData(p *Process, dataType string, data interface{}) (b []byte, err e
 		return nil, errors.New("I don't know how to marshal `" + dataType + "`.")
 	}
 
-	b, err = Marshallers[dataType](p, data)
+	b, err := Marshallers[dataType](p, data)
 	if err != nil {
 		return nil, errors.New("[" + dataType + " marshaller] " + err.Error())
 	}
 
-	return
+	return b, nil
 }
