@@ -92,12 +92,12 @@ func TestParseArray(t *testing.T) {
 			},
 			{
 				input:    "%[@TestParseArray]",
-				expected: `null`,
+				expected: `[]`,
 				pos:      16,
 			},
 			{
 				input:    "%[[@TestParseArray]]",
-				expected: `[null]`,
+				expected: `[[]]`,
 				pos:      18,
 			},
 			/////
@@ -214,3 +214,27 @@ func TestParseArrayObjects(t *testing.T) {
 
 	testParserObject(t, tests)
 }
+
+func TestParseArrayBugfix832(t *testing.T) {
+	tests := []test.MurexTest{
+		{
+			Block:  `%[]`,
+			Stdout: `^\[\]$`,
+		},
+		{
+			Block:  `out %[]`,
+			Stdout: `^\[\]\n$`,
+		},
+		{
+			Block:  `TestParseArrayBugfix832_3 = %[]; out $TestParseArrayBugfix832_3`,
+			Stdout: `^\[\]\n$`,
+		},
+		{
+			Block:   `TestParseArrayBugfix832_4 = %[]; out @TestParseArrayBugfix832_4`,
+			Stderr:  `Error`,
+			ExitNum: 1,
+		},
+	}
+
+	test.RunMurexTestsRx(tests, t)
+}
