@@ -12,6 +12,7 @@ import (
 	"github.com/lmorg/murex/lang/runmode"
 	"github.com/lmorg/murex/lang/state"
 	"github.com/lmorg/murex/lang/types"
+	"github.com/lmorg/murex/utils/crash"
 )
 
 const (
@@ -98,6 +99,8 @@ func (p *Process) Fork(flags int) *Fork {
 	fork.Process = new(Process)
 	fork.SetTerminatedState(true)
 	fork.Forks = p.Forks
+	trace(fork.Process)
+	fork.raw = p.raw
 
 	fork.State.Set(state.MemAllocated)
 	fork.Background.Set(flags&F_BACKGROUND != 0 || p.Background.Get())
@@ -138,8 +141,8 @@ func (p *Process) Fork(flags int) *Fork {
 	} else {
 		fork.Scope = p.Scope
 		fork.Name.Set(p.Name.String())
-		//fork.Parameters.CopyFrom(&p.Parameters)
 		fork.Context, fork.Done = p.Context, p.Done
+		fork.Kill = func() { deregisterProcess(fork.Process) }
 
 		if p.Scope.RunMode > runmode.Default {
 			fork.RunMode = p.Scope.RunMode
@@ -160,6 +163,7 @@ func (p *Process) Fork(flags int) *Fork {
 			fork.Name.Append(ForkSuffix)
 			GlobalFIDs.Register(fork.Process)
 			fork.fidRegistered = true
+			fork.IsFork = true
 
 		default:
 			//panic("must include either F_PARENT_VARTABLE or F_NEW_VARTABLE")
@@ -169,6 +173,7 @@ func (p *Process) Fork(flags int) *Fork {
 			fork.Name.Append(ForkSuffix)
 			GlobalFIDs.Register(fork.Process)
 			fork.fidRegistered = true
+			fork.IsFork = true
 		}
 
 		if flags&F_NEW_CONFIG != 0 {
@@ -228,18 +233,17 @@ func (p *Process) Fork(flags int) *Fork {
 	return fork
 }
 
+const (
+	_TRY_EXIT_NUM = false
+	_TRY_STDERR   = true
+)
+
 // Execute will run a murex code block
 func (fork *Fork) Execute(block []rune) (exitNum int, err error) {
-	switch {
-	case fork.FileRef == nil:
-		panic("fork.FileRef == nil in (fork *Fork).Execute()")
-	case fork.FileRef.Source == nil:
-		panic("fork.FileRef.Source == nil in (fork *Fork).Execute()")
-	case fork.FileRef.Source.Module == "":
-		panic("missing module name in (fork *Fork).Execute()")
-	case fork.Name.String() == "":
-		panic("missing function name in (fork *Fork).Execute()")
-	}
+	defer crash.Handler()
+	//defer runtime.GC() // just in case anyone fiddles with Go's garbage collector
+
+	forkCheckForNils(fork)
 
 	moduleRunMode := ModuleRunModes[fork.FileRef.Source.Module]
 	if moduleRunMode > 0 && fork.RunMode == 0 {
@@ -301,16 +305,16 @@ func (fork *Fork) Execute(block []rune) (exitNum int, err error) {
 		exitNum = 0
 
 	case runmode.BlockTry, runmode.FunctionTry, runmode.ModuleTry:
-		exitNum = runModeTry(procs, false)
+		exitNum = runModeTry(procs, _TRY_EXIT_NUM)
 
 	case runmode.BlockTryPipe, runmode.FunctionTryPipe, runmode.ModuleTryPipe:
-		exitNum = runModeTryPipe(procs, false)
+		exitNum = runModeTryPipe(procs, _TRY_EXIT_NUM)
 
 	case runmode.BlockTryErr, runmode.FunctionTryErr, runmode.ModuleTryErr:
-		exitNum = runModeTry(procs, true)
+		exitNum = runModeTry(procs, _TRY_STDERR)
 
 	case runmode.BlockTryPipeErr, runmode.FunctionTryPipeErr, runmode.ModuleTryPipeErr:
-		exitNum = runModeTryPipe(procs, true)
+		exitNum = runModeTryPipe(procs, _TRY_STDERR)
 
 	default:
 		panic("unknown run mode")
